@@ -184,18 +184,19 @@ text_frames = {
     id3.TRSN: "radiostationname",
     id3.TRSO: "radioowner",
     id3.TSIZ: "audiosize",
+    id3.TSO2: "albumartistsortorder",
     id3.TSOA: "albumsortorder",
     id3.TSOP: "performersortorder",
     id3.TSOT: "titlesortorder",
     id3.TSRC: "isrc",
     id3.TSSE: "encodingsettings",
     id3.TSST: "setsubtitle",
-    id3.TYER: 'year'}
+    id3.TYER: 'year',
+}
 
 try:
     text_frames.update({
         id3.TCMP: "itunescompilationflag",
-        id3.TSO2: "itunesalbumsortorder",
         id3.TSOC: "itunescomposersortorder"})
 except AttributeError:
     pass
@@ -816,27 +817,28 @@ def tag_factory(id3_filetype):
 
             util.MockTag.__init__(self, filename)
 
-        def get_filepath(self):
+        @property
+        def filepath(self):
             return util.MockTag.get_filepath(self)
 
-        def set_filepath(self, val):
+        @filepath.setter
+        def filepath(self, val):
             self.__tags.update(util.MockTag.set_filepath(self, val))
 
-        filepath = property(get_filepath, set_filepath)
-
-        def _get_images(self):
+        @property
+        def images(self):
             return self.__images
 
-        def _set_images(self, images):
+        @images.setter
+        def images(self, images):
             if images:
                 self.__images = [parse_image(i, self.IMAGETAGS) for i in images]
             else:
                 self.__images = []
             cover_info(images, self.__tags)
 
-        images = property(_get_images, _set_images)
-
-        def _info(self):
+        @property
+        def info(self):
             info = self.mut_obj.info
             fileinfo = [('Path', self[PATH]),
                         ('Size', str_filesize(int(self.size))),
@@ -853,7 +855,7 @@ def tag_factory(id3_filetype):
                 mpginfo = [('Type', 'DSF')]
             elif isinstance(self.mut_obj, AIFFFileType):
                 mpginfo = [('Type', 'AIFF')]
-            elif (self.mut_obj, ID3FileType):
+            elif isinstance(self.mut_obj, ID3FileType):
                 mpginfo = [('Version', 'MPEG %i Layer %i' % (info.version, info.layer))]
             else:
                 mpginfo = []
@@ -880,8 +882,6 @@ def tag_factory(id3_filetype):
 
             return [('File', fileinfo), (mpginfo[0][0], mpginfo)]
 
-        info = property(_info)
-
         def __contains__(self, key):
             if key == '__image':
                 return bool(self.images)
@@ -1022,7 +1022,7 @@ def tag_factory(id3_filetype):
                 if apics:
                     self.images = list(map(bin_to_pic, apics))
                 else:
-                    self.images = [];
+                    self.images = []
 
             self.__tags.update(tags)
             self.__tags.update(info_to_dict(audio.info))
