@@ -13,8 +13,8 @@ BLANK = translate('Defaults', '<blank>')
 KEEP = translate('Defaults', '<keep>')
 VARIOUS = translate('Defaults', 'Various')
 MUSICBRAINZ = translate('Defaults', 'MusicBrainz')
-SYNTAX_ERROR = translate('Defaults', 'SYNTAX ERROR in $%1: %2')
-SYNTAX_ARG_ERROR = translate('Defaults', 'SYNTAX ERROR: %s expects a number at argument %d.')
+SYNTAX_ERROR = translate('Defaults', "SYNTAX ERROR in ${}: {}")
+SYNTAX_ARG_ERROR = translate('Defaults', 'SYNTAX ERROR: {} expects a number at argument {}.')
 
 
 def trans_strings():
@@ -35,8 +35,8 @@ def trans_strings():
     KEEP = translate('Defaults', '<keep>')
     VARIOUS = translate('Defaults', 'Various Artists')
     MUSICBRAINZ = translate('Defaults', 'MusicBrainz')
-    SYNTAX_ERROR = translate('Defaults', 'SYNTAX ERROR in $%1: %2')
-    SYNTAX_ARG_ERROR = translate('Defaults', 'SYNTAX ERROR: %s expects a number at argument %d.')
+    SYNTAX_ERROR = translate('Defaults', "SYNTAX ERROR in ${}: {}")
+    SYNTAX_ARG_ERROR = translate('Defaults', 'SYNTAX ERROR: {} expects a number at argument {}.')
 
 
 SEPARATOR = '\\\\'
