@@ -37,18 +37,17 @@ import decimal
 import math
 import os
 import re
-import string
 import traceback
-import unicodedata
 from mutagen.mp3 import HeaderNotFoundError
 from collections import defaultdict
 from functools import partial
+from unidecode import unidecode
 
 import pyparsing
 
 from . import audioinfo
 from .audioinfo import encode_fn
-from .puddleobjects import (safe_name, fnmatch, natsort_case_key)
+from .puddleobjects import (safe_name, fnmatch, natural_sort_key)
 
 PATH = audioinfo.PATH
 DIRPATH = audioinfo.DIRPATH
@@ -276,15 +275,16 @@ def iflonger(a, b, text, text1):
 def import_text(m_tags, p_pattern, r_tags):
     '''Import text file, "Text File: $0, '$1'"
 &Pattern (can be relative path), text, lyrics.txt'''
-    path = os.path
-    dirpath = r_tags.dirpath
     filename = tag_to_filename(p_pattern, m_tags, r_tags, False)
     if not filename:
         return
     try:
-        return open(filename, 'r').read().decode('utf8')
+        with open(filename, 'tr', encoding='utf-8') as textfile:
+            return textfile.read()
     except EnvironmentError:
         return
+    except UnicodeDecodeError:
+        return
 
 
 def isdigit(text):
@@ -744,14 +744,7 @@ Match &Case, check"""
 
     def replace_matches(value):
         try:
-            try:
-                return re.sub(regex, replace_tokens, value, 0, flags)
-            except TypeError:
-                # Python2.6 doesn't accept flags arg.
-                if matchcase:
-                    return re.sub('(?i)' + regex, replace_tokens, value, 0)
-                else:
-                    return re.sub(regex, replace_tokens, value, 0)
+            return re.sub(regex, replace_tokens, value, 0, flags)
         except re.error as e:
             raise findfunc.FuncError(str(e))
 
@@ -760,14 +753,13 @@ Match &Case, check"""
 
 replace_regex = replaceWithReg
 
-VALID_FILENAME_CHARS = "'-_.!()[]{}&~+^ %s%s%s" % (
-    string.ascii_letters, string.digits, os.path.sep)
-
 
 # Contributed by Erik Reckase
+# Improved by David Gessel
 def to_ascii(t_fn):
-    cleaned_fn = unicodedata.normalize('NFKD', t_fn).encode('ASCII', 'ignore')
-    return ''.join(chr(c) for c in cleaned_fn if chr(c) in VALID_FILENAME_CHARS)
+    """Converts all unicode chars to ASCII."""
+    cleaned_fn = unidecode(t_fn, 'ignore')
+    return ''.join(c for c in cleaned_fn if c.isprintable())
 
 
 def remove_dupes(m_text, matchcase=False):
@@ -905,16 +897,12 @@ def sort_field(m_text, order='Ascending', matchcase=False):
 &Order, combo, Ascending, Descending,
 Match &Case, check"""
     text = m_text
-    if not matchcase:
-        key = natsort_case_key
-    else:
-        key = None
+
     if isinstance(text, str):
         return text
-    if order == 'Ascending':
-        return sorted(text, key=key)
-    else:
-        return sorted(text, key=key, reverse=True)
+    return sorted(text,
+                  key=lambda x: natural_sort_key(x, case_insensitive=not matchcase),
+                  reverse=order != 'Ascending')
 
 
 def split_by_sep(m_text, sep):
